==> huaweicloudsdkddm-3.1.136-py2.py3-none-any.whl: huaweicloudsdkddm/v1/model/show_logical_processes_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ShowLogicalProcessesResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'logical_processes': 'list[LogicalProcessInfo]',
        'total_count': 'int'
    }

    attribute_map = {
        'logical_processes': 'logical_processes',
        'total_count': 'total_count'
    }

    def __init__(self, logical_processes=None, total_count=None):
        """ShowLogicalProcessesResponse

        The model defined in huaweicloud sdk

        :param logical_processes: 逻辑会话列表
        :type logical_processes: list[:class:`huaweicloudsdkddm.v1.LogicalProcessInfo`]
        :param total_count: 总数
        :type total_count: int
        """
        
        super(ShowLogicalProcessesResponse, self).__init__()

        self._logical_processes = None
        self._total_count = None
        self.discriminator = None

        if logical_processes is not None:
            self.logical_processes = logical_processes
        if total_count is not None:
            self.total_count = total_count

    @property
    def logical_processes(self):
        """Gets the logical_processes of this ShowLogicalProcessesResponse.

        逻辑会话列表

        :return: The logical_processes of this ShowLogicalProcessesResponse.
        :rtype: list[:class:`huaweicloudsdkddm.v1.LogicalProcessInfo`]
        """
        return self._logical_processes

    @logical_processes.setter
    def logical_processes(self, logical_processes):
        """Sets the logical_processes of this ShowLogicalProcessesResponse.

        逻辑会话列表

        :param logical_processes: The logical_processes of this ShowLogicalProcessesResponse.
        :type logical_processes: list[:class:`huaweicloudsdkddm.v1.LogicalProcessInfo`]
        """
        self._logical_processes = logical_processes

    @property
    def total_count(self):
        """Gets the total_count of this ShowLogicalProcessesResponse.

        总数

        :return: The total_count of this ShowLogicalProcessesResponse.
        :rtype: int
        """
        return self._total_count

    @total_count.setter
    def total_count(self, total_count):
        """Sets the total_count of this ShowLogicalProcessesResponse.

        总数

        :param total_count: The total_count of this ShowLogicalProcessesResponse.
        :type total_count: int
        """
        self._total_count = total_count

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ShowLogicalProcessesResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkddm-3.1.154-py2.py3-none-any.whl: huaweicloudsdkddm/v1/model/show_logical_processes_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ShowLogicalProcessesResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'logical_processes': 'list[LogicalProcessInfo]',
        'total_count': 'int'
    }

    attribute_map = {
        'logical_processes': 'logical_processes',
        'total_count': 'total_count'
    }

    def __init__(self, logical_processes=None, total_count=None):
        r"""ShowLogicalProcessesResponse

        The model defined in huaweicloud sdk

        :param logical_processes: 逻辑会话列表
        :type logical_processes: list[:class:`huaweicloudsdkddm.v1.LogicalProcessInfo`]
        :param total_count: 总数
        :type total_count: int
        """
        
        super(ShowLogicalProcessesResponse, self).__init__()

        self._logical_processes = None
        self._total_count = None
        self.discriminator = None

        if logical_processes is not None:
            self.logical_processes = logical_processes
        if total_count is not None:
            self.total_count = total_count

    @property
    def logical_processes(self):
        r"""Gets the logical_processes of this ShowLogicalProcessesResponse.

        逻辑会话列表

        :return: The logical_processes of this ShowLogicalProcessesResponse.
        :rtype: list[:class:`huaweicloudsdkddm.v1.LogicalProcessInfo`]
        """
        return self._logical_processes

    @logical_processes.setter
    def logical_processes(self, logical_processes):
        r"""Sets the logical_processes of this ShowLogicalProcessesResponse.

        逻辑会话列表

        :param logical_processes: The logical_processes of this ShowLogicalProcessesResponse.
        :type logical_processes: list[:class:`huaweicloudsdkddm.v1.LogicalProcessInfo`]
        """
        self._logical_processes = logical_processes

    @property
    def total_count(self):
        r"""Gets the total_count of this ShowLogicalProcessesResponse.

        总数

        :return: The total_count of this ShowLogicalProcessesResponse.
        :rtype: int
        """
        return self._total_count

    @total_count.setter
    def total_count(self, total_count):
        r"""Sets the total_count of this ShowLogicalProcessesResponse.

        总数

        :param total_count: The total_count of this ShowLogicalProcessesResponse.
        :type total_count: int
        """
        self._total_count = total_count

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ShowLogicalProcessesResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
